A helper function to see what areas are available in boundaries_data. These area names can be passed to the boundaries argument of calc_index_areas().

available_areas()

Value

A character vector of available area names.

See also

Examples

# See all available areas
available_areas()
#>  [1] "Coastwide"                 "WA"                       
#>  [3] "OR"                        "CA"                       
#>  [5] "North of Point Conception" "South of Point Conception"
#>  [7] "North of Cape Mendocino"   "South of Cape Mendocino"  
#>  [9] "North of Monterey Bay"     "South of Monterey Bay"    

# Use in calc_index_areas()