Filter a grid created with lookup_grid()

filter_grid(boundary_north, boundary_south, grid)

Arguments

boundary_north, boundary_south

Real numbers providing the northern and southern latitudinal boundaries for your desired grid.

grid

A grid returned from lookup_grid().

Value

A data frame with the same structure as grid.

Author

Kelli F. Johnson