Format the strata for a species distribution model

format_strata(
  strata = nwfscSurvey::GetStrata.fn("coast"),
  min_depth = 55,
  max_depth = 1280
)

Arguments

strata

An object returned from nwfscSurvey::GetStrata.fn().

min_depth, max_depth

The minimum and maximum depths you want to use for all strata if you want to override the values in strata.

Examples

format_strata()
#> Warning: `GetStrata.fn()` was deprecated in nwfscSurvey 2.8.0.
#>  This function is no longer needed and will be removed in a future version.
#>   Please use get_strata_areas_default() instead.
#>  The deprecated feature was likely used in the indexwc package.
#>   Please report the issue at
#>   <https://github.com/pfmc-assessments/indexwc/issues>.
#> Warning: `CreateStrataDF.fn()` was deprecated in nwfscSurvey 2.8.0.
#>  This function is no longer needed and will be removed in a future version.
#>   Please use create_strata() instead.
#>  The deprecated feature was likely used in the nwfscSurvey package.
#>   Please report the issue to the authors.
#> Warning: `StrataAreas.fn()` was deprecated in nwfscSurvey 2.8.0.
#>  This function is no longer needed and will be removed in a future version.
#>   Please use get_strata_areas() instead.
#>  The deprecated feature was likely used in the nwfscSurvey package.
#>   Please report the issue to the authors.
#>     STRATA north_border south_border shallow_border deep_border
#> 1 ca_or_wa           49           32             55         549
#> 2       ca           42           32             55         549
#> 3       or           46           42             55         549
#> 4       wa           49           46             55         549
format_strata(nwfscSurvey::GetStrata.fn("sablefish"))
#> # A tibble: 3 × 5
#>   STRATA north_border south_border shallow_border deep_border
#>   <chr>         <dbl>        <dbl>          <dbl>       <dbl>
#> 1 coast            49           32             55        1280
#> 2 north            49           36             55        1280
#> 3 south            36           32             55        1280