Calculate index based upon the selected areas based on the prediction grid

get_area_results(
  area_name,
  area_bounds,
  full_pred,
  full_grid,
  calculate_cog = FALSE,
  bias_correct = TRUE
)

Arguments

area_name

A character vector specifying which areas to calculate indices for. These should be names from boundaries_data. The default is "Coastwide", which calculates only the Coastwide index

area_bounds

Prediction grid as modified by filter_boundaries() and boundaries.

full_pred

Object of model predictions created by stats::predict().

full_grid

Filtered grid created by filter_grid().

calculate_cog

Logical. If TRUE, center of gravity estimates will also be calculated using sdmTMB::get_cog() for each area. Defaults to FALSE. Note that COG results are returned in long format with separate rows for the X (easting) and Y (northing) coordinate axes.

bias_correct

Logical. If TRUE sdmTMB::get_index() and sdmTMB::get_cog() will use bias correction to account for the non-linear transformation of random effects when calculating the index. Will be faster if set to FALSE, but is TRUE by default

Details

Add details

Author

Kelli F. Johnson, Chantel Wetzel, and Eric Ward