Plot the data from a model fit by sdmTMB::sdmTMB()

map_residuals(data, n_row = 1, n_col = 2, save_prefix = NULL)

Arguments

data

A data frame with at least the following three columns:

n_row, n_col

Integers specifying the number of rows and columns for the faceted figures. The default is one row and two columns.

save_prefix

A string providing the desired prefix to use when saving the density plots. The default is to save them in the current working directory using the name "density[0-9]{2}.png". Obviously, the same outcome would result from just "density" but the use of fs::path() in the default is present to provide an example for users who want to change the path to something other than their current directory.

Author

Chantel R. Wetzel