Plot the annual parameter estimates from the fit model

plot_pars_fixed(fit, dir, file_name = "parameters_fixed_effects.png")

Arguments

fit

List created by sdmTMB::sdmTMB().

dir

A directory location where results and figures will be saved.

file_name

A string giving the file name. The default is "parameters_fixed_effects.png". If NULL, the file is not written but the ggplot object is returned

Author

Chantel R. Wetzel