Filter a grid created with lookup_grid()
filter_grid(boundary_north, boundary_south, grid)Real numbers providing the northern and southern latitudinal boundaries for your desired grid.
A grid returned from lookup_grid().
A data frame with the same structure as grid.