This data object represents the output of a call to rnaturalearth using mapdata <- rnaturalearth::ne_countries(scale = "medium", returnclass = "sf", country = "united states of america") and is included here to avoid dependencies on rnaturalearth
mapdataClass is sf and data.frame