Plot the indices
plot_indices(
data,
save_loc = getwd(),
file_name = "index.png",
legend_loc = "right"
)A data frame created by sdmTMB::get_index() with an additional
column giving the .id of each index called area. If area is not
not present, then all data points will be assumed to be from one default
area. It behooves you to make area an ordered factor such that the areas
are plotted in the order that you desire.
A string providing the location of the directory you wish to
save the png file to. The default is your current working directory, and if
NULL no directory will be created
A string giving the file name. The default is
"index.png". If NULL, the file is not written but the ggplot object is returned
Location for the legend to be added to the figure where
the options are "top", "bottom", "left", "right", or a vector of
length 2 giving relative coordinate positions. The default is "right".
Creates and saves a plot of the abundance indices in the directory location specified by the save_loc function input.
TODO
Think about adding some plotting information back in to have a title on the figure.