R/plot_pars_fixed.R
plot_pars_fixed.RdPlot the annual parameter estimates from the fit model
plot_pars_fixed(fit, dir, file_name = "parameters_fixed_effects.png")List created by sdmTMB::sdmTMB().
A directory location where results and figures will be saved.
A string giving the file name. The default is
"parameters_fixed_effects.png". If NULL, the file is not written but the ggplot object is returned